<?php
/**
 * @version     1.7.0RC1
 * @package     com_easytimetable
 * @copyright   Copyright (C) 2015. Tous droits réservés.
 * @license     GNU General Public License version 2 ou version ultérieure ; Voir LICENSE.txt
 * @author      Anthony Ceccarelli <contact@stereonomy.com> - http://www.stereonomy.com
 */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.controllerform');

/**
 * Activity controller class.
 */
class EasytimetableControllerActivity extends JControllerForm
{

    function __construct() {
        $this->view_list = 'activities';
        parent::__construct();
    }

    public function saveAct() {
        // Check for request forgeries.
        JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

        // Initialise variables.
        $app = JFactory::getApplication();
        $model = $this->getModel('Activity', 'EasytimetableModel');

        // Get the user data.
        $data = JFactory::getApplication()->input->get('jform', array(), 'array');

        // Validate the posted data.
        $form = $model->getForm();
        if (!$form) {
            JError::raiseError(500, $model->getError());
            return false;
        }

        // Validate the posted data.
        $data = $model->validate($form, $data);

        // Check for errors.
        if ($data === false) {
            // Get the validation messages.
            $errors = $model->getErrors();

            // Push up to three validation messages out to the user.
            for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++) {
                if ($errors[$i] instanceof Exception) {
                    $app->enqueueMessage($errors[$i]->getMessage(), 'warning');
                } else {
                    $app->enqueueMessage($errors[$i], 'warning');
                }
            }

            $input = $app->input;
            $jform = $input->get('jform', array(), 'ARRAY');

            // Save the data in the session.
            $app->setUserState('com_easytimetable.edit.activity.data', $jform, array());

            // Redirect back to the edit screen.
            $id = (int) $app->getUserState('com_easytimetable.edit.activity.id');
            $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=activity&layout=edit&id=' . $id, false));
            return false;
        }

        // Attempt to save the data.
        $return = $model->save($data);

        $result = new JResponseJson($return);

        $id = (int) $app->getUserState('com_easytimetable.edit.activity.id');
        
        $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=activity&id=' . $result->data, false));

        // Check for errors.
        if ($return === false) {
            // Save the data in the session.
            $app->setUserState('com_easytimetable.edit.activity.data', $data);

            // Redirect back to the edit screen.
            $id = (int) $app->getUserState('com_easytimetable.edit.activity.id');
            $this->setMessage(JText::sprintf('Save failed', $model->getError()), 'warning');
            $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=activity&layout=edit&id=' . $id, false));
            return false;
        }


        // Check in the profile.
        if ($return) {
            $model->checkin($return);
            $data2 = $app->setUserState('com_easytimetable.edit.activity.data', $data);
        }
        
        // Clear the profile id from the session.
        //$app->setUserState('com_easytimetable.edit.plannedactivity.id', null);

        

        // Redirect to the list screen.
        //$this->setMessage(JText::_('COM_EASYTIMETABLE_ITEM_SAVED_SUCCESSFULLY'));
        $menu = JFactory::getApplication()->getMenu();
        $item = $menu->getActive();
        $url = (empty($item->link) ? 'index.php?option=com_easytimetable&view=activities' : $item->link);
        $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=activity&format=raw&id=' . $result->data, false));

        // Flush the data from the session.
        //$app->setUserState('com_easytimetable.edit.plannedactivity.data', null);
    }

    public function remove() {

        JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

        // Initialise variables.
        $app = JFactory::getApplication();
        $model = $this->getModel('Activity', 'EasytimetableModel');

        // Get the user data.
        $data = array();
        $data['id'] = $app->input->getInt('id');

        // Check for errors.
        if (empty($data['id'])) {
            // Get the validation messages.
            $errors = $model->getErrors();

            // Push up to three validation messages out to the user.
            for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++) {
                if ($errors[$i] instanceof Exception) {
                    $app->enqueueMessage($errors[$i]->getMessage(), 'warning');
                } else {
                    $app->enqueueMessage($errors[$i], 'warning');
                }
            }

            // Save the data in the session.
            $app->setUserState('com_easytimetable.edit.activity.data', $data);

            // Redirect back to the edit screen.
            $id = (int) $app->getUserState('com_easytimetable.edit.activity.id');
            $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=activity&layout=edit&id=' . $id, false));
            return false;
        }

        // Attempt to save the data.
        $return = $model->delete($data);

        // Check for errors.
        if ($return === false) {
            // Save the data in the session.
            $app->setUserState('com_easytimetable.edit.activity.data', $data);

            // Redirect back to the edit screen.
            $id = (int) $app->getUserState('com_easytimetable.edit.activity.id');
            $this->setMessage(JText::sprintf('Delete failed', $model->getError()), 'warning');
            $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=activity&layout=edit&id=' . $id, false));
            return false;
        }


        // Check in the profile.
        if ($return) {
            $model->checkin($return);
        }

        // Clear the profile id from the session.
        $app->setUserState('com_easytimetable.edit.activity.id', null);

        // Redirect to the list screen.
        $this->setMessage(JText::_('COM_EASYTIMETABLE_ITEM_DELETED_SUCCESSFULLY'));
        $menu = JFactory::getApplication()->getMenu();
        $item = $menu->getActive();
        $url = (empty($item->link) ? 'index.php?option=com_easytimetable&view=activities' : $item->link);
        $this->setRedirect(JRoute::_($url, false));

        // Flush the data from the session.
        $app->setUserState('com_easytimetable.edit.activity.data', null);
    }

    /*
    Update assets rules to display the activity correctly to every user*/

    function setAsset() {
        // Initialise variables.
        $app = JFactory::getApplication();
        
        $model = $this->getModel('Activity', 'EasytimetableModel');
        $input = $app->input;
        // get id of the activity
        $id = $input->get('id');
        // update assets rules
        $model->setAssetRules($id);

    }

}