<?php
/**
 * @version    CVS: 1.2.1
 * @package    Com_Easytimetable
 * @author     Anthony Ceccarelli - Stereonomy <contact@stereonomy.com>
 * @copyright  Copyright (C) 2015. All rights reserved.
 * @license    GNU General Public License v2 or later ; See LICENSE.txt
 */

// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.controllerform');

/**
 * Field controller class.
 *
 * @since  1.6
 */
class EasytimetableControllerField extends JControllerForm
{
	/**
	 * Constructor
	 *
	 * @throws Exception
	 */
	public function __construct()
	{
		$this->view_list = 'fields';
		parent::__construct();
	}

	public function saveField() {
        // Check for request forgeries.
        JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

        // Initialise variables.
        $app = JFactory::getApplication();
        $model = $this->getModel('Field', 'EasytimetableModel');

        // Get the user data.
        $data = JFactory::getApplication()->input->get('jform', array(), 'array');
        // Validate the posted data.
        $form = $model->getForm();
        if (!$form) {
            JError::raiseError(500, $model->getError());
            return false;
        }

        // Validate the posted data.
        $data = $model->validate($form, $data);

        // Check for errors.
        if ($data === false) {
            // Get the validation messages.
            $errors = $model->getErrors();

            // Push up to three validation messages out to the user.
            for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++) {
                if ($errors[$i] instanceof Exception) {
                    $app->enqueueMessage($errors[$i]->getMessage(), 'warning');
                } else {
                    $app->enqueueMessage($errors[$i], 'warning');
                }
            }

            $input = $app->input;
            $jform = $input->get('jform', array(), 'ARRAY');

            // Save the data in the session.
            $app->setUserState('com_easytimetable.edit.field.data', $jform, array());

            // Redirect back to the edit screen.
            $id = (int) $app->getUserState('com_easytimetable.edit.field.id');
            $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=field&layout=edit&id=' . $id, false));
            return false;
        }

        // Attempt to save the data.
        $return = $model->save($data);
        $result = new JResponseJson($return);
        $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=field&id=' . $result->data, false));

        // Check for errors.
        if ($return === false) {
            // Save the data in the session.
            $app->setUserState('com_easytimetable.edit.field.data', $data);

            // Redirect back to the edit screen.
            $id = (int) $app->getUserState('com_easytimetable.edit.field.id');
            $this->setMessage(JText::sprintf('Save failed', $model->getError()), 'warning');
            $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=field&layout=edit&id=' . $id, false));
            return false;
        }


        // Check in the profile.
        if ($return) {
            $model->checkin($return);
            $data2 = $app->setUserState('com_easytimetable.edit.field.data', $data);
        }

        // Clear the profile id from the session.
        //$app->setUserState('com_easytimetable.edit.field.id', null);

        // Redirect to the list screen.
        //$this->setMessage(JText::_('COM_EASYTIMETABLE_ITEM_SAVED_SUCCESSFULLY'));
        $menu = JFactory::getApplication()->getMenu();
        $item = $menu->getActive();
        $url = (empty($item->link) ? 'index.php?option=com_easytimetable&view=fields' : $item->link);
        $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=field&format=raw&id=' . $result->data, false));

        // Flush the data from the session.
        //$app->setUserState('com_easytimetable.edit.field.data', null);
    }

    public function removeAjax() {

        JSession::checkToken() or jexit(JText::_('JINVALID_TOKEN'));

        // Initialise variables.
        $app = JFactory::getApplication();
        $model = $this->getModel('Field', 'EasytimetableModel');

        // Get the user data.
        $data = array();
        $data['id'] = $app->input->getInt('id');

        // Check for errors.
        if (empty($data['id'])) {
            // Get the validation messages.
            $errors = $model->getErrors();

            // Push up to three validation messages out to the user.
            for ($i = 0, $n = count($errors); $i < $n && $i < 3; $i++) {
                if ($errors[$i] instanceof Exception) {
                    $app->enqueueMessage($errors[$i]->getMessage(), 'warning');
                } else {
                    $app->enqueueMessage($errors[$i], 'warning');
                }
            }

            // Save the data in the session.
            $app->setUserState('com_easytimetable.edit.field.data', $data);

            // Redirect back to the edit screen.
            $id = (int) $app->getUserState('com_easytimetable.edit.field.id');
            $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=field&layout=edit&id=' . $id, false));
            return false;
        }

        // Attempt to save the data.
        $return = $model->delete($data);

        // Check for errors.
        if ($return === false) {
            // Save the data in the session.
            $app->setUserState('com_easytimetable.edit.field.data', $data);

            // Redirect back to the edit screen.
            $id = (int) $app->getUserState('com_easytimetable.edit.field.id');
            $this->setMessage(JText::sprintf('Delete failed', $model->getError()), 'warning');
            $this->setRedirect(JRoute::_('index.php?option=com_easytimetable&view=field&layout=edit&id=' . $id, false));
            return false;
        }


        // Check in the profile.
        if ($return) {
            $model->checkin($return);
        }

        // Clear the profile id from the session.
        $app->setUserState('com_easytimetable.edit.field.id', null);

        // Redirect to the list screen.
        //$this->setMessage(JText::_('COM_EASYTIMETABLE_ITEM_DELETED_SUCCESSFULLY'));
        //$menu = JFactory::getApplication()->getMenu();
        //$item = $menu->getActive();
        //$url = (empty($item->link) ? 'index.php?option=com_easytimetable&view=fields' : $item->link);
        //$this->setRedirect(JRoute::_($url, false));

        // Flush the data from the session.
        $app->setUserState('com_easytimetable.edit.field.data', null);
    }
}
