<?php
/**
 * @version    CVS: 1.2.1
 * @package    Com_Easytimetable
 * @author     Anthony Ceccarelli - Stereonomy <contact@stereonomy.com>
 * @copyright  Copyright (C) 2015. All rights reserved.
 * @license    GNU General Public License v2 or later ; See LICENSE.txt
 */

// No direct access.
defined('_JEXEC') or die;

jimport('joomla.application.component.modeladmin');

/**
 * Easytimetable model.
 *
 * @since  1.6
 */
class EasytimetableModelField extends JModelAdmin
{
	/**
	 * @var      string    The prefix to use with controller messages.
	 * @since    1.6
	 */
	protected $text_prefix = 'COM_EASYTIMETABLE';

	/**
	 * @var null  Item data
	 * @since  1.6
	 */
	protected $item = null;

	/**
	 * Returns a reference to the a Table object, always creating it.
	 *
	 * @param   string  $type    The table type to instantiate
	 * @param   string  $prefix  A prefix for the table class name. Optional.
	 * @param   array   $config  Configuration array for model. Optional.
	 *
	 * @return    JTable    A database object
	 *
	 * @since    1.6
	 */
	public function getTable($type = 'Field', $prefix = 'EasytimetableTable', $config = array())
	{
		return JTable::getInstance($type, $prefix, $config);
	}

	/**
	 * Method to get the record form.
	 *
	 * @param   array    $data      An optional array of data for the form to interogate.
	 * @param   boolean  $loadData  True if the form is to load its own data (default case), false if not.
	 *
	 * @return  JForm  A JForm object on success, false on failure
	 *
	 * @since    1.6
	 */
	public function getForm($data = array(), $loadData = true)
	{
		// Initialise variables.
		$app = JFactory::getApplication();

		// Get the form.
		$form = $this->loadForm(
			'com_easytimetable.field', 'field',
			array('control' => 'jform',
				'load_data' => $loadData
			)
		);

		if (empty($form))
		{
			return false;
		}

		return $form;
	}

	/**
	 * Method to get the data that should be injected in the form.
	 *
	 * @return   mixed  The data for the form.
	 *
	 * @since    1.6
	 */
	protected function loadFormData()
	{
		// Check the session for previously entered form data.
		$data = JFactory::getApplication()->getUserState('com_easytimetable.edit.field.data', array());

		if (empty($data))
		{
			if ($this->item === null)
			{
				$this->item = $this->getItem();
			}

			$data = $this->item;
			// Support for 'multiple' field
			$data->item_type = json_decode($data->item_type);
			$data->display_mode = json_decode($data->display_mode);
		}

		return $data;
	}

	/**
	 * Method to get a single record.
	 *
	 * @param   integer  $pk  The id of the primary key.
	 *
	 * @return  mixed    Object on success, false on failure.
	 *
	 * @since    1.6
	 */
	public function getItem($pk = null)
	{
		if ($item = parent::getItem($pk))
		{
			// Do any procesing on fields here if needed
		}

		return $item;
	}

	/**
	 * Method to get a single record.
	 *
	 * @param	integer	The id of the primary key.
	 *
	 * @return	mixed	Object on success, false on failure.
	 * @since	1.6
	 */
	public function getItemz($pk = null)
	{
		$data = JFactory::getApplication()->getUserState('com_easytimetable.edit.field.data', array());

		if ($item = parent::getItem($pk)) {
			//Do any procesing on fields here if needed
			$activity = implode(",", $data['activity']);
			$title = $data['title'];

			$text_field = $data['text_field'];
			dump($activity, 'activity');
			dump($title, 'title');
			dump($text_field, 'text_field');
			$db = JFactory::getDbo();
			$query = $db->getQuery(true);
			$query->select($db->quoteName('id'));
			$query->from($db->quoteName('#__com_easytimetable_field'));
			$query->where($db->quoteName('activity').'='.$activity);
			$query->where($db->quoteName('title').'='."'".$title."'");
			$query->where($db->quoteName('text_field').'='."'".$text_field."'");

			$db->setQuery($query);
			$item->id = $db->loadResult();
		}
		return $item->id;
		//$data = JFactory::getApplication()->setUserState('com_easytimetable.edit.field.data', null);
	}

	/**
	 * Method to duplicate a Field
	 *
	 * @param   array  &$pks  An array of primary key IDs.
	 *
	 * @return  boolean  True if successful.
	 *
	 * @throws  Exception
	 */
	public function duplicate(&$pks)
	{
		$user = JFactory::getUser();

		// Access checks.
		if (!$user->authorise('core.create', 'com_easytimetable'))
		{
			throw new Exception(JText::_('JERROR_CORE_CREATE_NOT_PERMITTED'));
		}

		$dispatcher = JEventDispatcher::getInstance();
		$context    = $this->option . '.' . $this->name;

		// Include the plugins for the save events.
		JPluginHelper::importPlugin($this->events_map['save']);

		$table = $this->getTable();

		foreach ($pks as $pk)
		{
			if ($table->load($pk, true))
			{
				// Reset the id to create a new record.
				$table->id = 0;

				if (!$table->check())
				{
					throw new Exception($table->getError());
				}
				
				if (!empty($table->activity))
				{
					if (is_array($table->activity))
					{
						$table->activity = implode(',', $table->activity);
					}
				}
				else
				{
					$table->activity = '';
				}

				if (!empty($table->timetable))
				{
					if (is_array($table->timetable))
					{
						$table->timetable = implode(',', $table->timetable);
					}
				}
				else
				{
					$table->timetable = '';
				}

				if (!empty($table->planned_activity))
				{
					if (is_array($table->planned_activity))
					{
						$table->planned_activity = implode(',', $table->planned_activity);
					}
				}
				else
				{
					$table->planned_activity = '';
				}


				// Trigger the before save event.
				$result = $dispatcher->trigger($this->event_before_save, array($context, &$table, true));

				if (in_array(false, $result, true) || !$table->store())
				{
					throw new Exception($table->getError());
				}

				// Trigger the after save event.
				$dispatcher->trigger($this->event_after_save, array($context, &$table, true));
			}
			else
			{
				throw new Exception($table->getError());
			}
		}

		// Clean cache
		$this->cleanCache();

		return true;
	}

	/**
	 * Prepare and sanitise the table prior to saving.
	 *
	 * @param   JTable  $table  Table Object
	 *
	 * @return void
	 *
	 * @since    1.6
	 */
	protected function prepareTable($table)
	{
		jimport('joomla.filter.output');

		if (empty($table->id))
		{
			// Set ordering to the last item if not set
			if (@$table->ordering === '')
			{
				$db = JFactory::getDbo();
				$db->setQuery('SELECT MAX(ordering) FROM #__com_easytimetable_field');
				$max             = $db->loadResult();
				$table->ordering = $max + 1;
			}
		}
	}
}
