<?php

/**
 * @version    CVS: 1.2.1
 * @package    Com_Easytimetable
 * @author     Anthony Ceccarelli - Stereonomy <contact@stereonomy.com>
 * @copyright  Copyright (C) 2015. All rights reserved.
 * @license    GNU General Public License v2 or later ; See LICENSE.txt
 */
defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Easytimetable records.
 *
 * @since  1.6
 */
class EasytimetableModelFields extends JModelList
{
/**
	* Constructor.
	*
	* @param   array  $config  An optional associative array of configuration settings.
	*
	* @see        JController
	* @since      1.6
	*/
	public function __construct($config = array())
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = array(
				'id', 'a.`id`',
				'title', 'a.`title`',
				'field_type', 'a.`field_type`',
				'item_type', 'a.`item_type`',
				'activity', 'a.`activity`',
				'timetable', 'a.`timetable`',
				'planned_activity', 'a.`planned_activity`',
				'display_title', 'a.`display_title`',
				'text_field', 'a.`text_field`',
				'text_area', 'a.`text_area`',
				'position', 'a.`position`',
				'image', 'a.`image`',
				'display_mode', 'a.`display_mode`',
				'field_index', 'a.`field_index`',
				'access', 'a.`access`',
				'state', 'a.`state`',
				'ordering', 'a.`ordering`',
				'created_by', 'a.`created_by`',
			);
		}

		parent::__construct($config);
	}

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param   string  $ordering   Elements order
	 * @param   string  $direction  Order direction
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication('administrator');

		// Load the filter state.
		$search = $app->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
		$this->setState('filter.search', $search);

		$published = $app->getUserStateFromRequest($this->context . '.filter.state', 'filter_published', '', 'string');
		$this->setState('filter.state', $published);
		// Filtering field_type
		$this->setState('filter.field_type', $app->getUserStateFromRequest($this->context.'.filter.field_type', 'filter_field_type', '', 'string'));

		// Filtering item_type
		$this->setState('filter.item_type', $app->getUserStateFromRequest($this->context.'.filter.item_type', 'filter_item_type', '', 'string'));

		// Filtering access
		$this->setState('filter.access', $app->getUserStateFromRequest($this->context.'.filter.access', 'filter_access', '', 'string'));


		// Load the parameters.
		$params = JComponentHelper::getParams('com_easytimetable');
		$this->setState('params', $params);

		// List state information.
		parent::populateState('a.text_area', 'asc');
	}

	/**
	 * Method to get a store id based on model configuration state.
	 *
	 * This is necessary because the model is used by the component and
	 * different modules that might need different sets of data or different
	 * ordering requirements.
	 *
	 * @param   string  $id  A prefix for the store id.
	 *
	 * @return   string A store id.
	 *
	 * @since    1.6
	 */
	protected function getStoreId($id = '')
	{
		// Compile the store id.
		$id .= ':' . $this->getState('filter.search');
		$id .= ':' . $this->getState('filter.state');

		return parent::getStoreId($id);
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return   JDatabaseQuery
	 *
	 * @since    1.6
	 */
	protected function getListQuery()
	{
		// Create a new query object.
		$db    = $this->getDbo();
		$query = $db->getQuery(true);

		// Select the required fields from the table.
		$query->select(
			$this->getState(
				'list.select', 'DISTINCT a.*'
			)
		);
		$query->from('`#__com_easytimetable_field` AS a');

		// Join over the users for the checked out user
		$query->select("uc.name AS editor");
		$query->join("LEFT", "#__users AS uc ON uc.id=a.checked_out");
		// Join over the foreign key 'activity'
		$query->select('#__com_easytimetable_activity_2033468.`act_name` AS activities_act_name_2033468');
		$query->join('LEFT', '#__com_easytimetable_activity AS #__com_easytimetable_activity_2033468 ON #__com_easytimetable_activity_2033468.`id` = a.`activity`');
		// Join over the foreign key 'timetable'
		$query->select('#__com_easytimetable_planning_2033485.`p_name` AS plannings_p_name_2033485');
		$query->join('LEFT', '#__com_easytimetable_planning AS #__com_easytimetable_planning_2033485 ON #__com_easytimetable_planning_2033485.`id` = a.`timetable`');
		// Join over the foreign key 'planned_activity'
		$query->select('#__com_easytimetable_acti_planning_2033488.`id` AS plannedactivities_id_2033488');
		$query->join('LEFT', '#__com_easytimetable_acti_planning AS #__com_easytimetable_acti_planning_2033488 ON #__com_easytimetable_acti_planning_2033488.`id` = a.`planned_activity`');

		// Join over the access level field 'access'
		$query->select('`access`.title AS `access`');
		$query->join('LEFT', '#__viewlevels AS access ON `access`.id = a.`access`');

		// Join over the user field 'created_by'
		$query->select('`created_by`.name AS `created_by`');
		$query->join('LEFT', '#__users AS `created_by` ON `created_by`.id = a.`created_by`');

		// Filter by published state
		$published = $this->getState('filter.state');

		if (is_numeric($published))
		{
			$query->where('a.state = ' . (int) $published);
		}
		elseif ($published === '')
		{
			$query->where('(a.state IN (0, 1))');
		}

		// Filter by search in title
		$search = $this->getState('filter.search');

		if (!empty($search))
		{
			if (stripos($search, 'id:') === 0)
			{
				$query->where('a.id = ' . (int) substr($search, 3));
			}
			else
			{
				$search = $db->Quote('%' . $db->escape($search, true) . '%');
				$query->where('( a.`text_area` LIKE ' . $search . ' )');
			}
		}


		//Filtering field_type
		$filter_field_type = $this->state->get("filter.field_type");
		if ($filter_field_type)
		{
			$query->where("a.`field_type` = '".$db->escape($filter_field_type)."'");
		}

		//Filtering item_type
		$filter_item_type = $this->state->get("filter.item_type");
		if ($filter_item_type)
		{
			$query->where("a.`item_type` LIKE '%\"".$db->escape($filter_item_type)."\"%'");
		}

		//Filtering access
		$filter_access = $this->state->get("filter.access");
		if ($filter_access)
		{
			$query->where("a.`access` = '".$db->escape($filter_access)."'");
		}
		// Add the list ordering clause.
		$orderCol  = $this->state->get('list.ordering');
		$orderDirn = $this->state->get('list.direction');

		if ($orderCol && $orderDirn)
		{
			$query->order($db->escape($orderCol . ' ' . $orderDirn));
		}

		return $query;
	}

	/**
	 * Get an array of data items
	 *
	 * @return mixed Array of data items on success, false on failure.
	 */
	public function getItems()
	{

		$store = $this->getStoreId();
        if (isset($this->cache[$store])){
            return $this->cache[$store];
        }
        $query = $this->_getListQuery();
        $items = $this->_getList($query, $this->getStart(), 0);  // Third arguments provides limit
        if ($this->_db->getErrorNum()){
            $this->setError($this->_db->getErrorMsg());
            return false;
        }
        $this->cache[$store] = $items;
        
        
		//$items = parent::getItems();

		foreach ($items as $oneItem) {
					$oneItem->field_type = JText::_('COM_EASYTIMETABLE_FIELDS_FIELD_TYPE_OPTION_' . strtoupper($oneItem->field_type));

				// Get the title of every option selected.

				$options = json_decode($oneItem->item_type);

				$options_text = array();

				foreach($options as $option){
						$options_text[] = JText::_('COM_EASYTIMETABLE_FIELDS_ITEM_TYPE_OPTION_' . strtoupper($option));

				}
					$oneItem->item_type = !empty($options_text) ? implode(',', $options_text) : $oneItem->item_type;

			if (isset($oneItem->activity)) {
				$values = explode(',', $oneItem->activity);

				$textValue = array();
				foreach ($values as $value){
					$db = JFactory::getDbo();
					$query = $db->getQuery(true);
					$query
							->select($db->quoteName('act_name'))
							->from('`#__com_easytimetable_activity`')
							->where($db->quoteName('id') . ' = '. $db->quote($db->escape($value)));
					$db->setQuery($query);
					$results = $db->loadObject();
					if ($results) {
						$textValue[] = $results->act_name;
					}
				}

			$oneItem->activity = !empty($textValue) ? implode(', ', $textValue) : $oneItem->activity;

			}

			if (isset($oneItem->timetable)) {
				$values = explode(',', $oneItem->timetable);

				$textValue = array();
				foreach ($values as $value){
					$db = JFactory::getDbo();
					$query = $db->getQuery(true);
					$query
							->select($db->quoteName('p_name'))
							->from('`#__com_easytimetable_planning`')
							->where($db->quoteName('id') . ' = '. $db->quote($db->escape($value)));
					$db->setQuery($query);
					$results = $db->loadObject();
					if ($results) {
						$textValue[] = $results->p_name;
					}
				}

			$oneItem->timetable = !empty($textValue) ? implode(', ', $textValue) : $oneItem->timetable;

			}

			if (isset($oneItem->planned_activity)) {
				$values = explode(',', $oneItem->planned_activity);

				$textValue = array();
				foreach ($values as $value){
					$db = JFactory::getDbo();
					$query = $db->getQuery(true);
					$query
							->select($db->quoteName('id'))
							->from('`#__com_easytimetable_acti_planning`')
							->where($db->quoteName('id') . ' = '. $db->quote($db->escape($value)));
					$db->setQuery($query);
					$results = $db->loadObject();
					if ($results) {
						$textValue[] = $results->id;
					}
				}

			$oneItem->planned_activity = !empty($textValue) ? implode(', ', $textValue) : $oneItem->planned_activity;

			}
					$oneItem->display_title = JText::_('COM_EASYTIMETABLE_FIELDS_DISPLAY_TITLE_OPTION_' . strtoupper($oneItem->display_title));
					$oneItem->position = JText::_('COM_EASYTIMETABLE_FIELDS_POSITION_OPTION_' . strtoupper($oneItem->position));

				// Get the title of every option selected.

				$options = json_decode($oneItem->display_mode, true);
				$optCount = count($options);
				
				$options_text = array();
				/*
				foreach($options as $option){
						$options_text[] = JText::_('COM_EASYTIMETABLE_FIELDS_DISPLAY_MODE_OPTION_' . strtoupper($option));

				}
				*/
				for ($i=0; $i < $optCount; $i++) { 
					$options_text[] = JText::_('COM_EASYTIMETABLE_FIELDS_DISPLAY_MODE_OPTION_' . strtoupper($options[$i]));
				}
					$oneItem->display_mode = !empty($options_text) ? implode(',', $options_text) : $oneItem->display_mode;
		}
		return $this->cache[$store];
	}

	public function getField($id) {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query
                ->select('*')
                ->from('#__com_easytimetable_field')
                ->where('id = ' . $id);
        $db->setQuery($query);
        return $db->loadObject();
    }
}
