<?php

/**
 * @version     1.7.0RC1
 * @package     com_easytimetable
 * @copyright   Copyright (C) 2015. Tous droits réservés.
 * @license     GNU General Public License version 2 ou version ultérieure ; Voir LICENSE.txt
 * @author      Anthony Ceccarelli <contact@stereonomy.com> - http://www.stereonomy.com
 */
defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Easytimetable records.
 */
class EasytimetableModelPlannedactivities extends JModelList {

    /**
     * Constructor.
     *
     * @param    array    An optional associative array of configuration settings.
     * @see        JController
     * @since    1.6
     */
    public function __construct($config = array()) {
        if (empty($config['filter_fields'])) {
            $config['filter_fields'] = array(
                'id', 'a.id',
                'id_activity', 'a.id_activity',
                'id_planning', 'a.id_planning',
                'id_cell', 'a.id_cell',
                'start_t', 'a.start_t',
                'end_t', 'a.end_t',
                'ordering', 'a.ordering',
                'state', 'a.state',
                'created_by', 'a.created_by',

            );
        }

        parent::__construct($config);
    }

    /**
     * Method to auto-populate the model state.
     *
     * Note. Calling getState in this method will result in recursion.
     */
    protected function populateState($ordering = null, $direction = null) {
        // Initialise variables.
        $app = JFactory::getApplication('administrator');

        // Load the filter state.
        $search = $app->getUserStateFromRequest($this->context . '.filter.search', 'filter_search');
        $this->setState('filter.search', $search);

        $published = $app->getUserStateFromRequest($this->context . '.filter.state', 'filter_published', '', 'string');
        $this->setState('filter.state', $published);

        

        // Load the parameters.
        $params = JComponentHelper::getParams('com_easytimetable');
        $this->setState('params', $params);

        // List state information.
        parent::populateState('a.id_activity', 'asc');
    }

    /**
     * Method to get a store id based on model configuration state.
     *
     * This is necessary because the model is used by the component and
     * different modules that might need different sets of data or different
     * ordering requirements.
     *
     * @param	string		$id	A prefix for the store id.
     * @return	string		A store id.
     * @since	1.6
     */
    protected function getStoreId($id = '') {
        // Compile the store id.
        $id.= ':' . $this->getState('filter.search');
        $id.= ':' . $this->getState('filter.state');

        return parent::getStoreId($id);
    }

    /**
     * Build an SQL query to load the list data.
     *
     * @return	JDatabaseQuery
     * @since	1.6
     */
    protected function getListQuery() {
        // Create a new query object.
        $db = $this->getDbo();
        $query = $db->getQuery(true);

        // Select the required fields from the table.
        $query->select(
                $this->getState(
                        'list.select', 'DISTINCT a.*'
                )
        );
        $query->from('`#__com_easytimetable_acti_planning` AS a');

        
		// Join over the users for the checked out user
		$query->select("uc.name AS editor");
		$query->join("LEFT", "#__users AS uc ON uc.id=a.checked_out");
		// Join over the user field 'created_by'
		$query->select('created_by.name AS created_by');
		$query->join('LEFT', '#__users AS created_by ON created_by.id = a.created_by');

        

		// Filter by published state
		$published = $this->getState('filter.state');
		if (is_numeric($published)) {
			$query->where('a.state = ' . (int) $published);
		} else if ($published === '') {
			$query->where('(a.state IN (0, 1))');
		}

        // Filter by search in title
        $search = $this->getState('filter.search');
        if (!empty($search)) {
            if (stripos($search, 'id:') === 0) {
                $query->where('a.id = ' . (int) substr($search, 3));
            } else {
                $search = $db->Quote('%' . $db->escape($search, true) . '%');
                $query->where('( a.id_activity LIKE '.$search.'  OR  a.id_planning LIKE '.$search.'  OR  a.id_cell LIKE '.$search.' OR  a.acti_name LIKE '.$search.' )');
            }
        }

        


        // Add the list ordering clause.
        $orderCol = $this->state->get('list.ordering');
        $orderDirn = $this->state->get('list.direction');
        if ($orderCol && $orderDirn) {
            $query->order($db->escape($orderCol . ' ' . $orderDirn));
        }

        return $query;
    }
    /*
    public function getItems() {
        $store = $this->getStoreId();
    if (isset($this->cache[$store])){
        return $this->cache[$store];
    }
    $query = $this->_getListQuery();
    $items = $this->_getList($query, $this->getStart(), 0);  // Third arguments provides limit
    if ($this->_db->getErrorNum()){
        $this->setError($this->_db->getErrorMsg());
        return false;
    }
    $this->cache[$store] = $items;
    return $this->cache[$store];
    }
*/
    /**
     * Get an array of data items
     *
     * @return mixed Array of data items on success, false on failure.
     */
    public function getItems()
    {
        $items = parent::getItems();

        return $items;
    }

    
    public function getPlannedAct($id_planning, $id_cell)
    {
        $db = JFactory::getDbo();
        $where = "";
        $where .= $db->quoteName('id_planning')." = ".$db->quote((int)$id_planning). "AND" ;
        $where .= $db->quoteName('id_cell')." = ".$db->quote((int)$id_cell) ;
        $query = $db->getQuery(true);
       
        $query
                ->select('*')
                ->from($db->quoteName('#__com_easytimetable_acti_planning'))
                ->where($where);
        $db->setQuery($query);

        $result = $db->loadObjectList();

        return $result;
    }

    public function getActi($id)
    {
        $db = JFactory::getDbo();
        $where = "";
        
        $where .= $db->quoteName('id')." = ".$db->quote((int)$id);
        $query = $db->getQuery(true);
        $query
                ->select('*')
                ->from($db->quoteName('#__com_easytimetable_activity'))
                ->where($where);
        $db->setQuery($query);

        $result = $db->loadObject();
        if(!is_null($result))
        {
            return $result;
        }
        
    }

    public function getTimetable($id)
    {
        $db = JFactory::getDbo();
        $where = "";
        
        $where .= $db->quoteName('id')." = ".$db->quote((int)$id);
        $query = $db->getQuery(true);
        $query
                ->select('*')
                ->from($db->quoteName('#__com_easytimetable_planning'))
                ->where($where);
        $db->setQuery($query);

        $result = $db->loadObject();
        if(!is_null($result))
        {
            return $result;
        }
        
    }

}
