<?php

/**
 * @version    CVS: 1.2.1
 * @package    Com_Easytimetable
 * @author     Anthony Ceccarelli - Stereonomy <contact@stereonomy.com>
 * @copyright  Copyright (C) 2015. All rights reserved.
 * @license    GNU General Public License v2 or later ; See LICENSE.txt
 */
// No direct access
defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * View class for a list of Easytimetable.
 *
 * @since  1.6
 */
class EasytimetableViewFields extends JViewLegacy
{
	protected $items;

	protected $pagination;

	protected $state;

	/**
	 * Display the view
	 *
	 * @param   string  $tpl  Template name
	 *
	 * @return void
	 *
	 * @throws Exception
	 */
	public function display($tpl = null)
	{
		$this->state = $this->get('State');
		$this->items = $this->get('Items');
		$this->pagination = $this->get('Pagination');

		// Check for errors.
		if (count($errors = $this->get('Errors')))
		{
			throw new Exception(implode("\n", $errors));
		}

		EasytimetableHelper::addSubmenu('fields');

		$this->addToolbar();

		$this->sidebar = JHtmlSidebar::render();
		parent::display($tpl);
	}

	/**
	 * Add the page title and toolbar.
	 *
	 * @return void
	 *
	 * @since    1.6
	 */
	protected function addToolbar()
	{
		require_once JPATH_COMPONENT . '/helpers/easytimetable.php';

		$state = $this->get('State');
		$canDo = EasytimetableHelper::getActions($state->get('filter.category_id'));

		JToolBarHelper::title(JText::_('COM_EASYTIMETABLE_TITLE_FIELDS'), 'fields.png');

		// Check if the form exists before showing the add/edit buttons
		$formPath = JPATH_COMPONENT_ADMINISTRATOR . '/views/field';

		if (file_exists($formPath))
		{
			if ($canDo->get('core.create'))
			{
				JToolBarHelper::addNew('field.add', 'JTOOLBAR_NEW');
				JToolbarHelper::custom('fields.duplicate', 'copy.png', 'copy_f2.png', 'JTOOLBAR_DUPLICATE', true);
			}

			if ($canDo->get('core.edit') && isset($this->items[0]))
			{
				JToolBarHelper::editList('field.edit', 'JTOOLBAR_EDIT');
			}
		}

		if ($canDo->get('core.edit.state'))
		{
			if (isset($this->items[0]->state))
			{
				JToolBarHelper::divider();
				JToolBarHelper::custom('fields.publish', 'publish.png', 'publish_f2.png', 'JTOOLBAR_PUBLISH', true);
				JToolBarHelper::custom('fields.unpublish', 'unpublish.png', 'unpublish_f2.png', 'JTOOLBAR_UNPUBLISH', true);
			}
			elseif (isset($this->items[0]))
			{
				// If this component does not use state then show a direct delete button as we can not trash
				JToolBarHelper::deleteList('', 'fields.delete', 'JTOOLBAR_DELETE');
			}

			if (isset($this->items[0]->state))
			{
				JToolBarHelper::divider();
				JToolBarHelper::archiveList('fields.archive', 'JTOOLBAR_ARCHIVE');
			}

			if (isset($this->items[0]->checked_out))
			{
				JToolBarHelper::custom('fields.checkin', 'checkin.png', 'checkin_f2.png', 'JTOOLBAR_CHECKIN', true);
			}
		}

		// Show trash and delete for components that uses the state field
		if (isset($this->items[0]->state))
		{
			if ($state->get('filter.state') == -2 && $canDo->get('core.delete'))
			{
				JToolBarHelper::deleteList('', 'fields.delete', 'JTOOLBAR_EMPTY_TRASH');
				JToolBarHelper::divider();
			}
			elseif ($canDo->get('core.edit.state'))
			{
				JToolBarHelper::trash('fields.trash', 'JTOOLBAR_TRASH');
				JToolBarHelper::divider();
			}
		}

		if ($canDo->get('core.admin'))
		{
			JToolBarHelper::preferences('com_easytimetable');
		}

		// Set sidebar action - New in 3.0
		JHtmlSidebar::setAction('index.php?option=com_easytimetable&view=fields');

		$this->extra_sidebar = '';
		//Filter for the field field_type
		/*$select_label = JText::sprintf('COM_EASYTIMETABLE_FILTER_SELECT_LABEL', 'Field Type');
		$options = array();
		$options[0] = new stdClass();
		$options[0]->value = "0";
		$options[0]->text = "text field";
		$options[1] = new stdClass();
		$options[1]->value = "1";
		$options[1]->text = "text area";
		$options[2] = new stdClass();
		$options[2]->value = "2";
		$options[2]->text = "Image";
		JHtmlSidebar::addFilter(
			$select_label,
			'filter_field_type',
			JHtml::_('select.options', $options , "value", "text", $this->state->get('filter.field_type'), true)
		);

		//Filter for the field item_type
		$select_label = JText::sprintf('COM_EASYTIMETABLE_FILTER_SELECT_LABEL', 'Item Type');
		$options = array();
		$options[0] = new stdClass();
		$options[0]->value = "0";
		$options[0]->text = "Activity";
		$options[1] = new stdClass();
		$options[1]->value = "1";
		$options[1]->text = "Timetable";
		$options[2] = new stdClass();
		$options[2]->value = "2";
		$options[2]->text = "Planned activity";
		JHtmlSidebar::addFilter(
			$select_label,
			'filter_item_type',
			JHtml::_('select.options', $options , "value", "text", $this->state->get('filter.item_type'), true)
		);*/

		JHtmlSidebar::addFilter(
			JText::_("JOPTION_SELECT_ACCESS"),
			'filter_access',
			JHtml::_('select.options', JHtml::_("access.assetgroups", true, true), "value", "text", $this->state->get('filter.access'), true)

		);

		JHtmlSidebar::addFilter(

			JText::_('JOPTION_SELECT_PUBLISHED'),

			'filter_published',

			JHtml::_('select.options', JHtml::_('jgrid.publishedOptions'), "value", "text", $this->state->get('filter.state'), true)

		);
	}

	/**
	 * Method to order fields 
	 *
	 * @return void 
	 */
	protected function getSortFields()
	{
		return array(
			'a.`id`' => JText::_('JGRID_HEADING_ID'),
			'a.`title`' => JText::_('COM_EASYTIMETABLE_FIELDS_TITLE'),
			'a.`field_type`' => JText::_('COM_EASYTIMETABLE_FIELDS_FIELD_TYPE'),
			'a.`item_type`' => JText::_('COM_EASYTIMETABLE_FIELDS_ITEM_TYPE'),
			'a.`activity`' => JText::_('COM_EASYTIMETABLE_FIELDS_ACTIVITY'),
			'a.`timetable`' => JText::_('COM_EASYTIMETABLE_FIELDS_TIMETABLE'),
			'a.`planned_activity`' => JText::_('COM_EASYTIMETABLE_FIELDS_PLANNED_ACTIVITY'),
			'a.`display_title`' => JText::_('COM_EASYTIMETABLE_FIELDS_DISPLAY_TITLE'),
			'a.`text_field`' => JText::_('COM_EASYTIMETABLE_FIELDS_TEXT_FIELD'),
			'a.`text_area`' => JText::_('COM_EASYTIMETABLE_FIELDS_TEXT_AREA'),
			'a.`position`' => JText::_('COM_EASYTIMETABLE_FIELDS_POSITION'),
			'a.`image`' => JText::_('COM_EASYTIMETABLE_FIELDS_IMAGE'),
			'a.`field_index`' => JText::_('COM_EASYTIMETABLE_FIELDS_FIELD_INDEX'),
			'a.`access`' => JText::_('COM_EASYTIMETABLE_FIELDS_ACCESS'),
			'a.`state`' => JText::_('JSTATUS'),
			'a.`ordering`' => JText::_('JGRID_HEADING_ORDERING'),
			'a.`created_by`' => JText::_('COM_EASYTIMETABLE_FIELDS_CREATED_BY'),
		);
	}
}
