<?php

/**
 * @version    CVS: 1.2.1
 * @package    Com_Easytimetable
 * @author     Anthony Ceccarelli - Stereonomy <contact@stereonomy.com>
 * @copyright  Copyright (C) 2015. All rights reserved.
 * @license    GNU General Public License v2 or later ; See LICENSE.txt
 */
defined('_JEXEC') or die;

jimport('joomla.application.component.modellist');

/**
 * Methods supporting a list of Easytimetable records.
 *
 * @since  1.6
 */
class EasytimetableModelFields extends JModelList
{
	/**
	 * Constructor.
	 *
	 * @param   array  $config  An optional associative array of configuration settings.
	 *
	 * @see        JController
	 * @since      1.6
	 */
	public function __construct($config = array())
	{
		if (empty($config['filter_fields']))
		{
			$config['filter_fields'] = array(
				'id', 'a.id',
				'title', 'a.title',
				'field_type', 'a.field_type',
				'item_type', 'a.item_type',
				'activity', 'a.activity',
				'timetable', 'a.timetable',
				'planned_activity', 'a.planned_activity',
				'display_title', 'a.display_title',
				'text_field', 'a.text_field',
				'text_area', 'a.text_area',
				'position', 'a.position',
				'image', 'a.image',
				'display_mode', 'a.display_mode',
				'field_index', 'a.field_index',
				'access', 'a.access',
				'state', 'a.state',
				'ordering', 'a.ordering',
				'created_by', 'a.created_by',
			);
		}

		parent::__construct($config);
	}

	/**
	 * Method to auto-populate the model state.
	 *
	 * Note. Calling getState in this method will result in recursion.
	 *
	 * @param   string  $ordering   Elements order
	 * @param   string  $direction  Order direction
	 *
	 * @return void
	 *
	 * @throws Exception
	 *
	 * @since    1.6
	 */
	protected function populateState($ordering = null, $direction = null)
	{
		// Initialise variables.
		$app = JFactory::getApplication();

		// List state information
		$limit = $app->getUserStateFromRequest('global.list.limit', 'limit', $app->get('list_limit'));
		$this->setState('list.limit', 10000000);

		$limitstart = $app->getUserStateFromRequest('limitstart', 'limitstart', 0);
		$this->setState('list.start', $limitstart);

		if ($list = $app->getUserStateFromRequest($this->context . '.list', 'list', array(), 'array'))
		{
			foreach ($list as $name => $value)
			{
				// Extra validations
				switch ($name)
				{
					case 'fullordering':
						$orderingParts = explode(' ', $value);

						if (count($orderingParts) >= 2)
						{
							// Latest part will be considered the direction
							$fullDirection = end($orderingParts);

							if (in_array(strtoupper($fullDirection), array('ASC', 'DESC', '')))
							{
								$this->setState('list.direction', $fullDirection);
							}

							unset($orderingParts[count($orderingParts) - 1]);

							// The rest will be the ordering
							$fullOrdering = implode(' ', $orderingParts);

							if (in_array($fullOrdering, $this->filter_fields))
							{
								$this->setState('list.ordering', $fullOrdering);
							}
						}
						else
						{
							$this->setState('list.ordering', $ordering);
							$this->setState('list.direction', $direction);
						}
						break;

					case 'ordering':
						if (!in_array($value, $this->filter_fields))
						{
							$value = $ordering;
						}
						break;

					case 'direction':
						if (!in_array(strtoupper($value), array('ASC', 'DESC', '')))
						{
							$value = $direction;
						}
						break;

					case 'limit':
						$limit = $value;
						break;

					// Just to keep the default case
					default:
						$value = $value;
						break;
				}

				$this->setState('list.' . $name, $value);
			}
		}

		// Receive & set filters
		if ($filters = $app->getUserStateFromRequest($this->context . '.filter', 'filter', array(), 'array'))
		{
			foreach ($filters as $name => $value)
			{
				$this->setState('filter.' . $name, $value);
			}
		}

		$ordering = $app->input->get('filter_order');

		if (!empty($ordering))
		{
			$list             = $app->getUserState($this->context . '.list');
			$list['ordering'] = $app->input->get('filter_order');
			$app->setUserState($this->context . '.list', $list);
		}

		$orderingDirection = $app->input->get('filter_order_Dir');

		if (!empty($orderingDirection))
		{
			$list              = $app->getUserState($this->context . '.list');
			$list['direction'] = $app->input->get('filter_order_Dir');
			$app->setUserState($this->context . '.list', $list);
		}

		$list = $app->getUserState($this->context . '.list');

		if (empty($list['ordering']))
{
	$list['ordering'] = 'ordering';
}

if (empty($list['direction']))
{
	$list['direction'] = 'asc';
}

		if (isset($list['ordering']))
		{
			$this->setState('list.ordering', $list['ordering']);
		}

		if (isset($list['direction']))
		{
			$this->setState('list.direction', $list['direction']);
		}
	}

	/**
	 * Build an SQL query to load the list data.
	 *
	 * @return   JDatabaseQuery
	 *
	 * @since    1.6
	 */
	protected function getListQuery()
	{
		// Create a new query object.
		$db    = $this->getDbo();
		$query = $db->getQuery(true);

		// Select the required fields from the table.
		$query
			->select(
				$this->getState(
					'list.select', 'DISTINCT a.*'
				)
			);

		$query->from('`#__com_easytimetable_field` AS a');
		
		// Join over the users for the checked out user.
		$query->select('uc.name AS editor');
		$query->join('LEFT', '#__users AS uc ON uc.id=a.checked_out');
		// Join over the foreign key 'activity'
		$query->select('#__com_easytimetable_activity_2033468.act_name AS activities_act_name_2033468');
		$query->join('LEFT', '#__com_easytimetable_activity AS #__com_easytimetable_activity_2033468 ON #__com_easytimetable_activity_2033468.id = a.activity');
		// Join over the foreign key 'timetable'
		$query->select('#__com_easytimetable_planning_2033485.p_name AS plannings_p_name_2033485');
		$query->join('LEFT', '#__com_easytimetable_planning AS #__com_easytimetable_planning_2033485 ON #__com_easytimetable_planning_2033485.id = a.timetable');
		// Join over the foreign key 'planned_activity'
		$query->select('#__com_easytimetable_acti_planning_2033488.id AS plannedactivities_id_2033488');
		$query->join('LEFT', '#__com_easytimetable_acti_planning AS #__com_easytimetable_acti_planning_2033488 ON #__com_easytimetable_acti_planning_2033488.id = a.planned_activity');

		// Join over the created by field 'created_by'
		$query->join('LEFT', '#__users AS created_by ON created_by.id = a.created_by');
		
		if (!JFactory::getUser()->authorise('core.edit.state', 'com_easytimetable'))
		{
			$query->where('a.state = 1');
		}

		// Filter by search in title
		$search = $this->getState('filter.search');

		if (!empty($search))
		{
			if (stripos($search, 'id:') === 0)
			{
				$query->where('a.id = ' . (int) substr($search, 3));
			}
			else
			{
				$search = $db->Quote('%' . $db->escape($search, true) . '%');
$query->where('( a.text_area LIKE '.$search.' )');
			}
		}
		

		// Filtering field_type
		$filter_field_type = $this->state->get("filter.field_type");
		if ($filter_field_type != '') {
			$query->where("a.field_type = '".$db->escape($filter_field_type)."'");
		}

		// Filtering item_type
		$filter_item_type = $this->state->get("filter.item_type");
		if ($filter_item_type != '') {
			$query->where("a.item_type LIKE '%\"".$db->escape($filter_item_type)."\"%'");
		}

		// Filtering access
		$filter_access = $this->state->get("filter.access");
		if ($filter_access != '') {
			$query->where("a.access = '".$db->escape($filter_access)."'");
		}

		// Add the list ordering clause.
		$orderCol  = $this->state->get('list.ordering');
		$orderDirn = $this->state->get('list.direction');

		if ($orderCol && $orderDirn)
		{
			$query->order($db->escape($orderCol . ' ' . $orderDirn));
		}

		return $query;
	}

	/**
	 * Method to get an array of data items
	 *
	 * @return  mixed An array of data on success, false on failure.
	 */
	public function getItems()
	{
		$items = parent::getItems();
		
		foreach ($items as $item)
		{

					$item->field_type = JText::_('COM_EASYTIMETABLE_FIELDS_FIELD_TYPE_OPTION_' . strtoupper($item->field_type));
				// Get the title of every option selected.
				$options = json_decode($item->item_type);
				$options_text = array();

				foreach ($options as $option)
				{
						$options_text[] = JText::_('COM_EASYTIMETABLE_FIELDS_ITEM_TYPE_OPTION_' . strtoupper($option));

				}
					$item->item_type = !empty($options_text) ? implode(',', $options_text) : $item->item_type;			

				if (isset($item->activity) && $item->activity != '')
				{
				if (is_object($item->activity))
				{
					$item->activity = ArrayHelper::fromObject($item->activity);
				}

				$values = (is_array($item->activity)) ? $item->activity : explode(',', $item->activity);
				$textValue = array();

				foreach ($values as $value)
				{
					$db = JFactory::getDbo();
					$query = $db->getQuery(true);
					$query
							->select($db->quoteName('act_name'))
							->from('`#__com_easytimetable_activity`')
							->where($db->quoteName('id') . ' = ' . $db->quote($db->escape($value)));
					$db->setQuery($query);
					$results = $db->loadObject();

					if ($results)
					{
						$textValue[] = $results->act_name;
					}
				}

				$item->activity = !empty($textValue) ? implode(', ', $textValue) : $item->activity;
			}			if (isset($item->timetable) && $item->timetable != '')
			{
				if (is_object($item->timetable))
				{
					$item->timetable = ArrayHelper::fromObject($item->timetable);
				}

				$values = (is_array($item->timetable)) ? $item->timetable : explode(',', $item->timetable);
				$textValue = array();

				foreach ($values as $value)
				{
					$db = JFactory::getDbo();
					$query = $db->getQuery(true);
					$query
							->select($db->quoteName('p_name'))
							->from('`#__com_easytimetable_planning`')
							->where($db->quoteName('id') . ' = ' . $db->quote($db->escape($value)));
					$db->setQuery($query);
					$results = $db->loadObject();

					if ($results)
					{
						$textValue[] = $results->p_name;
					}
				}

				$item->timetable = !empty($textValue) ? implode(', ', $textValue) : $item->timetable;
			}			if (isset($item->planned_activity) && $item->planned_activity != '')
			{
				if (is_object($item->planned_activity))
				{
					$item->planned_activity = ArrayHelper::fromObject($item->planned_activity);
				}

				$values = (is_array($item->planned_activity)) ? $item->planned_activity : explode(',', $item->planned_activity);
				$textValue = array();

				foreach ($values as $value)
				{
					$db = JFactory::getDbo();
					$query = $db->getQuery(true);
					$query
							->select($db->quoteName('id'))
							->from('`#__com_easytimetable_acti_planning`')
							->where($db->quoteName('id') . ' = ' . $db->quote($db->escape($value)));
					$db->setQuery($query);
					$results = $db->loadObject();

					if ($results)
					{
						$textValue[] = $results->id;
					}
				}

				$item->planned_activity = !empty($textValue) ? implode(', ', $textValue) : $item->planned_activity;
			}
				$item->display_title = JText::_('COM_EASYTIMETABLE_FIELDS_DISPLAY_TITLE_OPTION_' . strtoupper($item->display_title));
				$item->position = JText::_('COM_EASYTIMETABLE_FIELDS_POSITION_OPTION_' . strtoupper($item->position));

				// Get the title of every option selected.

				$options = json_decode($item->display_mode, true);
				$optCount = count($options);

				$options_text = array();
				/*
				foreach ($options as $option)
				{
						$options_text[] = JText::_('COM_EASYTIMETABLE_FIELDS_DISPLAY_MODE_OPTION_' . strtoupper($option));
				}
				*/
				for ($i=0; $i < $optCount; $i++) { 
					$options_text[] = JText::_('COM_EASYTIMETABLE_FIELDS_DISPLAY_MODE_OPTION_' . strtoupper($options[$i]));
				}
				$item->display_mode = !empty($options_text) ? implode(',', $options_text) : $item->display_mode;
		}

		return $items;
	}

	public function getField($id) {
        $db = JFactory::getDbo();
        $query = $db->getQuery(true);
        $query
                ->select('*')
                ->from('#__com_easytimetable_field')
                ->where('id = ' . $id);
        $db->setQuery($query);
        return $db->loadObject();
    }

	/**
	 * Overrides the default function to check Date fields format, identified by
	 * "_dateformat" suffix, and erases the field if it's not correct.
	 *
	 * @return void
	 */
	protected function loadFormData()
	{
		$app              = JFactory::getApplication();
		$filters          = $app->getUserState($this->context . '.filter', array());
		$error_dateformat = false;

		foreach ($filters as $key => $value)
		{
			if (strpos($key, '_dateformat') && !empty($value) && $this->isValidDate($value) == null)
			{
				$filters[$key]    = '';
				$error_dateformat = true;
			}
		}

		if ($error_dateformat)
		{
			$app->enqueueMessage(JText::_("COM_EASYTIMETABLE_SEARCH_FILTER_DATE_FORMAT"), "warning");
			$app->setUserState($this->context . '.filter', $filters);
		}

		return parent::loadFormData();
	}

	/**
	 * Checks if a given date is valid and in a specified format (YYYY-MM-DD)
	 *
	 * @param   string  $date  Date to be checked
	 *
	 * @return bool
	 */
	private function isValidDate($date)
	{
		$date = str_replace('/', '-', $date);
		return (date_create($date)) ? JFactory::getDate($date)->format("Y-m-d") : null;
	}
}
